@@ -253,10 +253,15 @@ def translate(content: str = None, target_lang: str = user_lang):
             )
     if content:
         retry = 3
-        lang = requirePackage('langid', 'classify')(content)[0]
+        lang = requirePackage("langid", "classify")(content)[0]
         while retry:
             try:
-                ret = _translate(content, target_lang="en" if target_lang == user_lang and lang == user_lang else target_lang)
+                ret = _translate(
+                    content,
+                    target_lang="en"
+                    if target_lang == user_lang and lang == user_lang
+                    else target_lang,
+                )
                 break
             except SSLError:
                 retry -= 1
@@ -1202,7 +1207,65 @@ def gpt():
     ChatGPT-3.5
     :return:
     """
-    wait_all = '--wait-all' in sys.argv
+    translate_text = "--translate" in sys.argv
+    if translate_text:
+        from commonmark.blocks import Parser
+        from commonmark.render.rst import ReStructuredTextRenderer
+
+        parser = Parser()
+        sys.argv.remove("--translate")
+
+        class TranslateRenderer(ReStructuredTextRenderer):
+            def __init__(self):
+                super().__init__()
+
+            def text(self, node, entering):
+                self.out(translate(node.literal))
+
+            def link(self, node, entering):
+                if entering:
+                    self.out("[")
+                else:
+                    self.out("](%s)" % node.destination)
+
+            def image(self, node, entering):
+                if entering:
+                    self.out("![")
+                else:
+                    self.out(f"]({node.destination})")
+
+            def code(self, node, entering):
+                self.out("`")
+                self.out(node.literal)
+                self.out("`")
+
+            def code_block(self, node, entering):
+                directive = "```"
+                language_name = None
+
+                info_words = node.info.split() if node.info else []
+                if len(info_words) > 0 and len(info_words[0]) > 0:
+                    language_name = info_words[0]
+
+                if language_name:
+                    directive += language_name
+
+                self.cr()
+                self.out(directive)
+                self.cr()
+                self.out(node.literal)
+                self.out("```")
+                self.cr()
+
+            def heading(self, node, entering):
+                if entering:
+                    self.cr()
+                    self.out("#" * node.level)
+                    self.out(" ")
+                else:
+                    self.cr()
+
+        render = TranslateRenderer()
 
     from rich.markdown import Markdown
     from rich.live import Live
@@ -1214,6 +1277,11 @@ def gpt():
         qs_info_string, "Type 'exit' to exit" if user_lang != "zh" else "输入 'exit' 退出"
     )
 
+    if not translate_text:
+        qs_default_console.print(
+            qs_info_string, "Add '--translate' to enable auto translate" if user_lang != "zh" else "添加 '--translate' 以启用自动翻译"
+        )
+
     record = ""
 
     while (
@@ -1224,6 +1292,10 @@ def gpt():
             }
         )
     ) != "exit":
+        if translate_text:
+            prompt = translate(prompt, target_lang="en")
+            qs_default_console.print("EN:", prompt)
+        
         with qs_default_status("Thinking..." if user_lang != "zh" else "思考中..."):
             response = chatGPT(prompt)
 
@@ -1231,20 +1303,31 @@ def gpt():
             "[bold green]" + ("Answer" if user_lang != "zh" else "回答") + "[/]\n",
             justify="center",
         )
-        prefix = '' if prompt not in ['继续', 'continue'] else record
+        prefix = "" if prompt not in ["继续", "continue"] else record
 
-        if wait_all:
-            total_res = prefix + response
-            qs_default_console.print(Markdown(display = '\n'.join([' '.join(cut_string(line, qs_default_console.width, ignore_charset='`')) for line in total_res.split('\n')])))
+        with Live("", console=qs_default_console, auto_refresh=False) as live:
+            total_res = prefix
+            for res in response:
+                if API_KEY or ALAPI:
+                    total_res += res
+                else:
+                    total_res = prefix + res["message"]
+                display = "\n".join(
+                    [
+                        " ".join(
+                            cut_string(
+                                line, qs_default_console.width, ignore_charset="`"
+                            )
+                        )
+                        for line in total_res.split("\n")
+                    ]
+                )
+                live.update(Markdown(display, justify="full"), refresh=True)
             record = total_res
-        else:
-            with Live('', console=qs_default_console, auto_refresh=False) as live:
-                total_res = prefix
-                for res in response:
-                    if API_KEY or ALAPI:
-                        total_res += res
-                    else:
-                        total_res = prefix + res['message']
-                    display = '\n'.join([' '.join(cut_string(line, qs_default_console.width, ignore_charset='`')) for line in total_res.split('\n')])
-                    live.update(Markdown(display, justify='full'), refresh=True)
-                record = total_res
+            # if translate_text:
+            #     live.update(
+            #         Markdown(
+            #             render.render(parser.parse(total_res)), justify="full"
+            #         ),
+            #         refresh=True,
+            #     )
